from .... pyaz_utils import _call_az

def show(managed_instance, resource_group):
    '''
    

    Required Parameters:
    - managed_instance -- Name of the Azure SQL managed instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql mi tde-key show", locals())


def set(managed_instance, resource_group, server_key_type, auto_rotation_enabled=None, kid=None):
    '''
    Sets the SQL Instance's encryption protector.

    Required Parameters:
    - managed_instance -- Name of the Azure SQL managed instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_key_type -- The type of the server key

    Optional Parameters:
    - auto_rotation_enabled -- The key auto rotation opt in status. Can be either true or false.
    - kid -- The Azure Key Vault key identifier of the server key. An example key identifier is "https://YourVaultName.vault.azure.net/keys/YourKeyName/01234567890123456789012345678901"
    '''
    return _call_az("az sql mi tde-key set", locals())




from .... pyaz_utils import _call_az
from . import rule


def show(account_name, policy_id, resource_group=None):
    '''
    Show the properties of specified Object Replication Service Policy for storage account.

    Required Parameters:
    - account_name -- The storage account name.
    - policy_id -- The ID of object replication policy or "default" if the policy ID is unknown. Policy Id will be auto-generated when setting on destination account. Required when setting on source account.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account or-policy show", locals())


def list(account_name, resource_group=None):
    '''
    List Object Replication Service Policies associated with the specified storage account.

    Required Parameters:
    - account_name -- The storage account name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account or-policy list", locals())


def create(account_name, destination_account=None, destination_container=None, min_creation_time=None, policy=None, policy_id=None, prefix_match=None, resource_group=None, rule_id=None, source_account=None, source_container=None):
    '''
    Create Object Replication Service Policy for storage account.

    Required Parameters:
    - account_name -- The storage account name.

    Optional Parameters:
    - destination_account -- The destination storage account name or resource Id. Apply --account-name value as destination account when there is no destination account provided in --policy and --destination-account.
    - destination_container -- The destination storage container name. Required when no --policy provided.
    - min_creation_time -- Blobs created after the time will be replicated to the destination. It must be in datetime format 'yyyy-MM-ddTHH:mm:ssZ'. Example: 2020-02-19T16:05:00Z
    - policy -- The object replication policy definition between two storage accounts, in JSON format. Multiple rules can be defined in one policy.
    - policy_id -- The ID of object replication policy or "default" if the policy ID is unknown. Policy Id will be auto-generated when setting on destination account. Required when setting on source account.
    - prefix_match -- Optional. Filter the results to replicate only blobs whose names begin with the specified prefix.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_id -- Rule Id is auto-generated for each new rule on destination account. It is required for put policy on source account.
    - source_account -- The source storage account name or resource Id. Required when no --policy provided.
    - source_container -- The source storage container name. Required when no --policy provided.
    '''
    return _call_az("az storage account or-policy create", locals())


def update(account_name, add=None, destination_account=None, force_string=None, policy=None, policy_id=None, remove=None, resource_group=None, set=None, source_account=None):
    '''
    Update Object Replication Service Policy properties for storage account.

    Required Parameters:
    - account_name -- The storage account name.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - destination_account -- The destination storage account name or resource Id. Apply --account-name value as destination account when there is no destination account provided in --policy and --destination-account.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - policy -- The object replication policy definition between two storage accounts, in JSON format. Multiple rules can be defined in one policy.
    - policy_id -- The ID of object replication policy or "default" if the policy ID is unknown. Policy Id will be auto-generated when setting on destination account. Required when setting on source account.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - source_account -- The source storage account name or resource Id. Required when no --policy provided.
    '''
    return _call_az("az storage account or-policy update", locals())


def delete(account_name, policy_id, resource_group=None):
    '''
    Delete specified Object Replication Service Policy associated with the specified storage account.

    Required Parameters:
    - account_name -- The storage account name.
    - policy_id -- The ID of object replication policy or "default" if the policy ID is unknown. Policy Id will be auto-generated when setting on destination account. Required when setting on source account.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account or-policy delete", locals())




'''
Manage HDInsight resources.
'''
from .. pyaz_utils import _call_az
from . import application, autoscale, azure_monitor, host, monitor, script_action


def create(name, resource_group, type, assign_identity=None, autoscale_max_workernode_count=None, autoscale_min_workernode_count=None, autoscale_type=None, autoscale_workernode_count=None, cluster_admin_account=None, cluster_admin_password=None, cluster_configurations=None, cluster_tier=None, cluster_users_group_dns=None, component_version=None, days=None, domain=None, edgenode_size=None, enable_compute_isolation=None, enable_private_link=None, encryption_algorithm=None, encryption_at_host=None, encryption_in_transit=None, encryption_key_name=None, encryption_key_version=None, encryption_vault_uri=None, esp=None, headnode_size=None, host_sku=None, http_password=None, http_user=None, idbroker=None, kafka_client_group_id=None, kafka_client_group_name=None, kafka_management_node_count=None, kafka_management_node_size=None, ldaps_urls=None, location=None, minimal_tls_version=None, no_validation_timeout=None, no_wait=None, private_link_config=None, resource_provider_connection=None, ssh_password=None, ssh_public_key=None, ssh_user=None, storage_account=None, storage_account_key=None, storage_account_managed_identity=None, storage_container=None, storage_filesystem=None, subnet=None, tags=None, time=None, timezone=None, version=None, vnet_name=None, workernode_count=None, workernode_data_disk_size=None, workernode_data_disk_storage_account_type=None, workernode_data_disks_per_node=None, workernode_size=None, zones=None, zookeepernode_size=None):
    '''
    Create a new cluster.

    Required Parameters:
    - name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - type -- Type of HDInsight cluster, like: hadoop, interactivehive, hbase, kafka, storm, spark, rserver, mlservices. See also: https://docs.microsoft.com/azure/hdinsight/hdinsight-hadoop-provision-linux-clusters#cluster-types

    Optional Parameters:
    - assign_identity -- The name or ID of user assigned identity.
    - autoscale_max_workernode_count -- The max workernode count for Load-based atuoscale.
    - autoscale_min_workernode_count -- The minimal workernode count for Load-based atuoscale.
    - autoscale_type -- The autoscale type.
    - autoscale_workernode_count -- The scheduled workernode count.
    - cluster_admin_account -- The domain user account that will have admin privileges on the cluster. Required only when create cluster with Enterprise Security Package.
    - cluster_admin_password -- The domain admin password. Required only when create cluster with Enterprise Security Package.
    - cluster_configurations -- Extra configurations of various components. Configurations may be supplied from a file using the `@{path}` syntax or a JSON string. See also: https://docs.microsoft.com/azure/hdinsight/hdinsight-hadoop-customize-cluster-bootstrap
    - cluster_tier -- The tier of the cluster
    - cluster_users_group_dns -- A space-delimited list of Distinguished Names for cluster user groups. Required only when create cluster with Enterprise Security Package. 
    - component_version -- The versions of various Hadoop components, in space-separated versions in 'component=version' format. Example: Spark=2.0 Hadoop=2.7.3 See also: https://docs.microsoft.com/azure/hdinsight/hdinsight-component-versioning#hadoop-components-available-with-different-hdinsight-versions
    - days -- A space-delimited list of schedule day.
    - domain -- The name or resource ID of the user's Azure Active Directory Domain Service. Required only when create cluster with Enterprise Security Package.
    - edgenode_size -- The size of the node. See also: https://docs.microsoft.com/azure/hdinsight/hdinsight-hadoop-provision-linux-clusters#configure-cluster-size
    - enable_compute_isolation -- Indicate whether enable compute isolation or not.
    - enable_private_link -- Indicate whether enable the private link or not.
    - encryption_algorithm -- Algorithm identifier for encryption.
    - encryption_at_host -- Indicates whether enable encryption at host or not.
    - encryption_in_transit -- Indicates whether enable encryption in transit.
    - encryption_key_name -- Key name that is used for enabling disk encryption.
    - encryption_key_version -- Key version that is used for enabling disk encryption.
    - encryption_vault_uri -- Base key vault URI where the customers key is located eg. https://myvault.vault.azure.net
    - esp -- Specify to create cluster with Enterprise Security Package. If omitted, creating cluster with Enterprise Security Package will not not allowed.
    - headnode_size -- The size of the node. See also: https://docs.microsoft.com/azure/hdinsight/hdinsight-hadoop-provision-linux-clusters#configure-cluster-size
    - host_sku -- The dedicated host sku of compute isolation.
    - http_password -- HTTP password for the cluster. Will prompt if not given.
    - http_user -- HTTP username for the cluster.  Default: admin.
    - idbroker -- Specify to create ESP cluster with HDInsight ID Broker. If omitted, creating ESP cluster with HDInsight ID Broker will not not allowed.
    - kafka_client_group_id -- The client AAD security group id for Kafka Rest Proxy
    - kafka_client_group_name -- The client AAD security group name for Kafka Rest Proxy
    - kafka_management_node_count -- The number of kafka management node in the cluster
    - kafka_management_node_size -- The size of the node. See also: https://docs.microsoft.com/azure/hdinsight/hdinsight-hadoop-provision-linux-clusters#configure-cluster-size
    - ldaps_urls -- A space-delimited list of LDAPS protocol URLs to communicate with the Active Directory. Required only when create cluster with Enterprise Security Package.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - minimal_tls_version -- The minimal supported TLS version.
    - no_validation_timeout -- Permit timeout error during argument validation phase. If omitted, validation timeout error will be permitted.
    - no_wait -- Do not wait for the long-running operation to finish.
    - private_link_config -- The private link configurations when creating cluster. Private Link Configurations may be supplied from a file using the `@{path}` syntax or a JSON string. Please see https://github.com/Azure/azure-cli/blob/dev/src/azure-cli/azure/cli/command_modules/hdinsight/tests/latest/privatelinkconfigurations.json
    - resource_provider_connection -- The resource provider connection type
    - ssh_password -- SSH password for the cluster nodes. If none specified, uses the HTTP password.
    - ssh_public_key -- SSH public key for the cluster nodes.
    - ssh_user -- SSH username for the cluster nodes.
    - storage_account -- The name or ID of the storage account.
    - storage_account_key -- The storage account key. A key can be retrieved automatically if the user has access to the storage account.
    - storage_account_managed_identity -- User-assigned managed identity with access to the storage account filesystem. Only required when storage account type is Azure Data Lake Storage Gen2.
    - storage_container -- The storage container the cluster will use. Uses the cluster name if none was specified. (WASB only)
    - storage_filesystem -- The storage filesystem the cluster will use. Uses the cluster name if none was specified. (DFS only)
    - subnet -- The name or ID of subnet. If name is supplied, `--vnet-name` must be supplied.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - time -- The 24-hour time in the form of xx:xx in days.
    - timezone -- The timezone for schedule autoscale type. Values from `az hdinsight autoscale list-timezones`
    - version -- The HDInsight cluster version. See also: https://docs.microsoft.com/azure/hdinsight/hdinsight-component-versioning#supported-hdinsight-versions
    - vnet_name -- The name of a virtual network.
    - workernode_count -- The number of worker nodes in the cluster.
    - workernode_data_disk_size -- The size of the data disk in GB, e.g. 1023.
    - workernode_data_disk_storage_account_type -- The type of storage account that will be used for the data disks: standard_lrs or premium_lrs
    - workernode_data_disks_per_node -- The number of data disks to use per worker node.
    - workernode_size -- The size of the node. See also: https://docs.microsoft.com/azure/hdinsight/hdinsight-hadoop-provision-linux-clusters#configure-cluster-size
    - zones -- A space-delimited list of availability zones where cluster will be created.
    - zookeepernode_size -- The size of the node. See also: https://docs.microsoft.com/azure/hdinsight/hdinsight-hadoop-provision-linux-clusters#configure-cluster-size
    '''
    return _call_az("az hdinsight create", locals())


def resize(name, resource_group, workernode_count, no_wait=None):
    '''
    Resize the specified HDInsight cluster to the specified size.

    Required Parameters:
    - name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workernode_count -- The target worker node instance count for the operation.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az hdinsight resize", locals())


def show(name, resource_group):
    '''
    

    Required Parameters:
    - name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az hdinsight show", locals())


def list(resource_group=None):
    '''
    List HDInsight clusters in a resource group or subscription.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az hdinsight list", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until an operation is complete.

    Required Parameters:
    - name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az hdinsight wait", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    

    Required Parameters:
    - name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az hdinsight delete", locals())


def rotate_disk_encryption_key(encryption_key_name, encryption_key_version, encryption_vault_uri, name, resource_group, no_wait=None):
    '''
    Rotate the disk encryption key of the specified HDInsight cluster.

    Required Parameters:
    - encryption_key_name -- Key name that is used for enabling disk encryption.
    - encryption_key_version -- Key version that is used for enabling disk encryption.
    - encryption_vault_uri -- Base key vault URI where the customers key is located eg. https://myvault.vault.azure.net
    - name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az hdinsight rotate-disk-encryption-key", locals())


def update(name, resource_group, no_wait=None, tags=None):
    '''
    Update the tags of the specified HDInsight cluster.

    Required Parameters:
    - name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az hdinsight update", locals())


def list_usage(location):
    '''
    

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az hdinsight list-usage", locals())




'''
Manage extensions on VMs.
'''
from ... pyaz_utils import _call_az
from . import image


def delete(name, resource_group, vm_name, no_wait=None):
    '''
    Remove an extension attached to a VM.

    Required Parameters:
    - name -- Name of the extension.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vm_name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az vm extension delete", locals())


def show(name, resource_group, vm_name, expand=None):
    '''
    Display information about extensions attached to a VM.

    Required Parameters:
    - name -- Name of the extension.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vm_name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`

    Optional Parameters:
    - expand -- The expand expression to apply on the operation.
    '''
    return _call_az("az vm extension show", locals())


def set(name, publisher, resource_group, vm_name, enable_auto_upgrade=None, extension_instance_name=None, force_update=None, no_auto_upgrade_minor_version=None, no_wait=None, protected_settings=None, settings=None, version=None):
    '''
    Set extensions for a VM.

    Required Parameters:
    - name -- Name of the extension.
    - publisher -- The name of the extension publisher.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vm_name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`

    Optional Parameters:
    - enable_auto_upgrade -- Indicate the extension should be automatically upgraded by the platform if there is a newer version of the extension available.
    - extension_instance_name -- Name of extension instance, which can be customized. Default: name of the extension.
    - force_update -- force to update even if the extension configuration has not changed.
    - no_auto_upgrade_minor_version -- If set, the extension service will not automatically pick or upgrade to the latest minor version, even if the extension is redeployed.
    - no_wait -- Do not wait for the long-running operation to finish.
    - protected_settings -- Protected settings in JSON format for sensitive information like credentials. A JSON file path is also accepted.
    - settings -- Extension settings in JSON format. A JSON file path is also accepted.
    - version -- The version of the extension. To pin extension version to this value, please specify --no-auto-upgrade-minor-version.
    '''
    return _call_az("az vm extension set", locals())


def list(resource_group, vm_name):
    '''
    List the extensions attached to a VM.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vm_name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    '''
    return _call_az("az vm extension list", locals())


def wait(name, resource_group, vm_name, created=None, custom=None, deleted=None, exists=None, expand=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a virtual machine extension is met.

    Required Parameters:
    - name -- Name of the extension.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vm_name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - expand -- The expand expression to apply on the operation.
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az vm extension wait", locals())




from .... pyaz_utils import _call_az

def list(custom_domains, date_time_begin, date_time_end, granularity, metrics, profile_name, protocols, resource_group, continents=None, country_or_regions=None, group_by=None):
    '''
    

    Required Parameters:
    - custom_domains -- The domains to be included.
    - date_time_begin -- The start datetime.
    - date_time_end -- The end datetime.
    - granularity -- The interval granularity.
    - metrics -- Metric types to include.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - protocols -- The protocols to be included.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - continents -- ISO 3316-1 alpha-2 continent code.
    - country_or_regions -- ISO 3316-1 alpha-2 region code.
    - group_by -- Aggregate demensions.
    '''
    return _call_az("az afd log-analytic metric list", locals())




'''
Configure a web app.
'''
from ... pyaz_utils import _call_az
from . import access_restriction, appsettings, backup, connection_string, container, hostname, snapshot, ssl, storage_account


def set(name, resource_group, always_on=None, auto_heal_enabled=None, ftps_state=None, generic_configurations=None, http20_enabled=None, java_container=None, java_container_version=None, java_version=None, linux_fx_version=None, min_tls_version=None, net_framework_version=None, number_of_workers=None, php_version=None, prewarmed_instance_count=None, python_version=None, remote_debugging_enabled=None, slot=None, startup_file=None, use_32bit_worker_process=None, vnet_route_all_enabled=None, web_sockets_enabled=None, windows_fx_version=None):
    '''
    Set a web app's configuration.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - always_on -- ensure web app gets loaded all the time, rather unloaded after been idle. Recommended when you have continuous web jobs running
    - auto_heal_enabled -- enable or disable auto heal
    - ftps_state -- Set the Ftps state value for an app. Default value is 'AllAllowed'.
    - generic_configurations -- Provide site configuration list in a format of either `key=value` pair or `@<json_file>`. PowerShell and Windows Command Prompt users should use a JSON file to provide these configurations to avoid compatibility issues with escape characters.
    - http20_enabled -- configures a web site to allow clients to connect over http2.0.
    - java_container -- The java container, e.g., Tomcat, Jetty
    - java_container_version -- The version of the java container, e.g., '8.0.23' for Tomcat
    - java_version -- The version used to run your web app if using Java, e.g., '1.7' for Java 7, '1.8' for Java 8
    - linux_fx_version -- The runtime stack used for your linux-based webapp, e.g., "RUBY|2.5.5", "NODE|10.14", "PHP|7.2", "DOTNETCORE|2.1". See https://aka.ms/linux-stacks for more info.
    - min_tls_version -- The minimum version of TLS required for SSL requests, e.g., '1.0', '1.1', '1.2'
    - net_framework_version -- The version used to run your web app if using .NET Framework, e.g., 'v4.0' for .NET 4.6 and 'v3.0' for .NET 3.5
    - number_of_workers -- The number of workers to be allocated.
    - php_version -- The version used to run your web app if using PHP, e.g., 5.5, 5.6, 7.0
    - prewarmed_instance_count -- Number of pre-warmed instances a function app has
    - python_version -- The version used to run your web app if using Python, e.g., 2.7, 3.4
    - remote_debugging_enabled -- enable or disable remote debugging
    - slot -- the name of the slot. Default to the productions slot if not specified
    - startup_file -- The startup file for linux hosted web apps, e.g. 'process.json' for Node.js web
    - use_32bit_worker_process -- use 32 bits worker process or not
    - vnet_route_all_enabled -- Configure regional VNet integration to route all traffic to the VNet.
    - web_sockets_enabled -- enable or disable web sockets
    - windows_fx_version -- A docker image name used for your windows container web app, e.g., microsoft/nanoserver:ltsc2016
    '''
    return _call_az("az webapp config set", locals())


def show(name, resource_group, slot=None):
    '''
    Get the details of a web app's configuration.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp config show", locals())




from ... pyaz_utils import _call_az

def approve(account_name=None, description=None, id=None, name=None, resource_group=None):
    '''
    Approve the specified private endpoint connection associated with Azure Cosmos DB.

    Optional Parameters:
    - account_name -- Name of the Cosmos DB database account. Required if --connection-id is not specified
    - description -- Comments for the approve operation.
    - id -- The ID of the private endpoint connection associated with Azure Cosmos DB. If specified --account-name --resource-group/-g and --name/-n, this should be omitted.
    - name -- The name of the private endpoint connection associated with Azure Cosmos DB. Required if --connection-id is not specified
    - resource_group -- The resource group name of specified Cosmos DB account. Required if --connection-id is not specified
    '''
    return _call_az("az cosmosdb private-endpoint-connection approve", locals())


def reject(account_name=None, description=None, id=None, name=None, resource_group=None):
    '''
    Reject the specified private endpoint connection associated with Azure Cosmos DB.

    Optional Parameters:
    - account_name -- Name of the Cosmos DB database account. Required if --connection-id is not specified
    - description -- Comments for the reject operation.
    - id -- The ID of the private endpoint connection associated with Azure Cosmos DB. If specified --account-name --resource-group/-g and --name/-n, this should be omitted.
    - name -- The name of the private endpoint connection associated with Azure Cosmos DB. Required if --connection-id is not specified
    - resource_group -- The resource group name of specified Cosmos DB account. Required if --connection-id is not specified
    '''
    return _call_az("az cosmosdb private-endpoint-connection reject", locals())


def delete(account_name=None, id=None, name=None, resource_group=None):
    '''
    Delete the specified private endpoint connection associated with Azure Cosmos DB.

    Optional Parameters:
    - account_name -- Name of the Cosmos DB database account. Required if --connection-id is not specified
    - id -- The ID of the private endpoint connection associated with Azure Cosmos DB. If specified --account-name --resource-group/-g and --name/-n, this should be omitted.
    - name -- The name of the private endpoint connection associated with Azure Cosmos DB. Required if --connection-id is not specified
    - resource_group -- The resource group name of specified Cosmos DB account. Required if --connection-id is not specified
    '''
    return _call_az("az cosmosdb private-endpoint-connection delete", locals())


def show(account_name=None, id=None, name=None, resource_group=None):
    '''
    Show details of a private endpoint connection associated with Azure Cosmos DB.

    Optional Parameters:
    - account_name -- Name of the Cosmos DB database account. Required if --connection-id is not specified
    - id -- The ID of the private endpoint connection associated with Azure Cosmos DB. If specified --account-name --resource-group/-g and --name/-n, this should be omitted.
    - name -- The name of the private endpoint connection associated with Azure Cosmos DB. Required if --connection-id is not specified
    - resource_group -- The resource group name of specified Cosmos DB account. Required if --connection-id is not specified
    '''
    return _call_az("az cosmosdb private-endpoint-connection show", locals())




from .... pyaz_utils import _call_az

def create(eventhub_name, name, namespace_name, resource_group, user_metadata=None):
    '''
    Creates the EventHub ConsumerGroup

    Required Parameters:
    - eventhub_name -- Name of EventHub
    - name -- Name of ConsumerGroup
    - namespace_name -- name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - user_metadata -- Usermetadata is a placeholder to store user-defined string data with maximum length 1024. e.g. it can be used to store descriptive data, such as list of teams and their contact information also user-defined configuration settings can be stored.
    '''
    return _call_az("az eventhubs eventhub consumer-group create", locals())


def show(eventhub_name, name, namespace_name, resource_group):
    '''
    Shows the ConsumerGroup Details

    Required Parameters:
    - eventhub_name -- Name of EventHub
    - name -- Name of ConsumerGroup
    - namespace_name -- name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventhubs eventhub consumer-group show", locals())


def list(eventhub_name, namespace_name, resource_group, skip=None, top=None):
    '''
    List the ConsumerGroup by Eventhub

    Required Parameters:
    - eventhub_name -- Name of EventHub
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - skip -- Skip is only used if a previous operation returned a partial result. If a previous response contains a nextLink element, the value of the nextLink element will include a skip parameter that specifies a starting point to use for subsequent calls.
    - top -- May be used to limit the number of results to the most recent N usageDetails.
    '''
    return _call_az("az eventhubs eventhub consumer-group list", locals())


def delete(eventhub_name, name, namespace_name, resource_group):
    '''
    Deletes the ConsumerGroup

    Required Parameters:
    - eventhub_name -- Name of EventHub
    - name -- Name of ConsumerGroup
    - namespace_name -- name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventhubs eventhub consumer-group delete", locals())


def update(eventhub_name, name, namespace_name, resource_group, add=None, force_string=None, remove=None, set=None, user_metadata=None):
    '''
    Updates the EventHub ConsumerGroup

    Required Parameters:
    - eventhub_name -- Name of EventHub
    - name -- Name of ConsumerGroup
    - namespace_name -- name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - user_metadata -- Usermetadata is a placeholder to store user-defined string data with maximum length 1024. e.g. it can be used to store descriptive data, such as list of teams and their contact information also user-defined configuration settings can be stored.
    '''
    return _call_az("az eventhubs eventhub consumer-group update", locals())




from ... pyaz_utils import _call_az

def list(standard_name):
    '''
    List supported of regulatory compliance controls details and state for selected standard.

    Required Parameters:
    - standard_name -- The compliance standard name
    '''
    return _call_az("az security regulatory-compliance-controls list", locals())


def show(name, standard_name):
    '''
    Shows a regulatory compliance details state for selected standard.

    Required Parameters:
    - name -- name of the resource to be fetched
    - standard_name -- The compliance standard name
    '''
    return _call_az("az security regulatory-compliance-controls show", locals())




'''
Manage Azure Container Services.
'''
from .. pyaz_utils import _call_az
from . import dcos, kubernetes


def browse(name, resource_group, disable_browser=None, ssh_key_file=None):
    '''
    Show the dashboard for a service container's orchestrator in a web browser.

    Required Parameters:
    - name -- Name of the container service. You can configure the default using `az configure --defaults acs=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - disable_browser -- Do not open browser after opening a proxy to the cluster web user interface
    - ssh_key_file -- If set a path to an SSH key to use, only applies to DCOS
    '''
    return _call_az("az acs browse", locals())


def create(name, resource_group, admin_password=None, admin_username=None, agent_count=None, agent_osdisk_size=None, agent_ports=None, agent_profiles=None, agent_storage_profile=None, agent_vm_size=None, agent_vnet_subnet_id=None, api_version=None, client_secret=None, deployment_name=None, dns_prefix=None, generate_ssh_keys=None, location=None, master_count=None, master_first_consecutive_static_ip=None, master_osdisk_size=None, master_profile=None, master_storage_profile=None, master_vm_size=None, master_vnet_subnet_id=None, no_wait=None, orchestrator_type=None, orchestrator_version=None, service_principal=None, ssh_key_value=None, tags=None, validate=None, windows=None):
    '''
    Create a new container service.

    Required Parameters:
    - name -- Name of the container service. You can configure the default using `az configure --defaults acs=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - admin_password -- The adminstration password for Windows nodes. Only available if --windows=true
    - admin_username -- User name for the Linux Virtual Machines.
    - agent_count -- None
    - agent_osdisk_size -- Feature in preview, only in canadacentral, canadaeast, centralindia, koreasouth, koreacentral, southindia, uksouth, ukwest, westcentralus, westindia, westus2. Set the default disk size for agent pools vms. Unit in GB. Default: corresponding vmsize disk size
    - agent_ports -- Feature in preview, only in canadacentral, canadaeast, centralindia, koreasouth, koreacentral, southindia, uksouth, ukwest, westcentralus, westindia, westus2. Set the default ports exposed on the agent pools. Only usable for non-Kubernetes. Default: 8080,4000,80
    - agent_profiles -- Feature in preview, only in canadacentral, canadaeast, centralindia, koreasouth, koreacentral, southindia, uksouth, ukwest, westcentralus, westindia, westus2. The file or dictionary representation of the agent profiles. Note it will override any agent settings once set
    - agent_storage_profile -- Feature in preview, only in canadacentral, canadaeast, centralindia, koreasouth, koreacentral, southindia, uksouth, ukwest, westcentralus, westindia, westus2. Set default storage profile for agent pools. Default: varies based on Orchestrator
    - agent_vm_size -- Set the default size for agent pools vms.
    - agent_vnet_subnet_id -- Feature in preview, only in canadacentral, canadaeast, centralindia, koreasouth, koreacentral, southindia, uksouth, ukwest, westcentralus, westindia, westus2. Set the default custom vnet subnet id for agent pools. Note agent need to used the same vnet if master set. Default: ""
    - api_version -- Feature in preview, only in canadacentral, canadaeast, centralindia, koreasouth, koreacentral, southindia, uksouth, ukwest, westcentralus, westindia, westus2. Use API version of ACS to perform az acs operations. Available options: 2017-01-31, 2017-07-01. Default: the latest version for the location
    - client_secret -- None
    - deployment_name -- ==SUPPRESS==
    - dns_prefix -- Sets the Domain name prefix for the cluster. The concatenation of the domain name and the regionalized DNS zone make up the fully qualified domain name associated with the public IP address.
    - generate_ssh_keys -- Generate SSH public and private key files if missing
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - master_count -- The number of masters for the cluster.
    - master_first_consecutive_static_ip -- Feature in preview, only in canadacentral, canadaeast, centralindia, koreasouth, koreacentral, southindia, uksouth, ukwest, westcentralus, westindia, westus2. The first consecutive ip used to specify static ip block.
    - master_osdisk_size -- Feature in preview, only in canadacentral, canadaeast, centralindia, koreasouth, koreacentral, southindia, uksouth, ukwest, westcentralus, westindia, westus2. The disk size for master pool vms. Unit in GB. Default: corresponding vmsize disk size
    - master_profile -- Feature in preview, only in canadacentral, canadaeast, centralindia, koreasouth, koreacentral, southindia, uksouth, ukwest, westcentralus, westindia, westus2. The file or dictionary representation of the master profile. Note it will override any master settings once set
    - master_storage_profile -- Feature in preview, only in canadacentral, canadaeast, centralindia, koreasouth, koreacentral, southindia, uksouth, ukwest, westcentralus, westindia, westus2. Default: varies based on Orchestrator
    - master_vm_size -- Feature in preview, only in canadacentral, canadaeast, centralindia, koreasouth, koreacentral, southindia, uksouth, ukwest, westcentralus, westindia, westus2. 
    - master_vnet_subnet_id -- Feature in preview, only in canadacentral, canadaeast, centralindia, koreasouth, koreacentral, southindia, uksouth, ukwest, westcentralus, westindia, westus2. The custom vnet subnet id. Note agent need to used the same vnet if master set. Default: ""
    - no_wait -- Do not wait for the long-running operation to finish.
    - orchestrator_type -- The type of orchestrator used to manage the applications on the cluster.
    - orchestrator_version -- Feature in preview, only in canadacentral, canadaeast, centralindia, koreasouth, koreacentral, southindia, uksouth, ukwest, westcentralus, westindia, westus2. Use Orchestrator Version to specify the semantic version for your choice of orchestrator.
    - service_principal -- None
    - ssh_key_value -- Configure all linux machines with the SSH RSA public key string.  Your key should include three parts, for example 'ssh-rsa AAAAB...snip...UcyupgH azureuser@linuxvm
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - validate -- Generate and validate the ARM template without creating any resources
    - windows -- If true, set the default osType of agent pools to be Windows.
    '''
    return _call_az("az acs create", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete a container service.

    Required Parameters:
    - name -- Name of the container service. You can configure the default using `az configure --defaults acs=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az acs delete", locals())


def list(resource_group=None):
    '''
    List container services.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acs list", locals())


def list_locations():
    '''
    List locations where Azure Container Service is in preview and in production.
    '''
    return _call_az("az acs list-locations", locals())


def scale(name, new_agent_count, resource_group):
    '''
    Change the private agent count of a container service.

    Required Parameters:
    - name -- Name of the container service. You can configure the default using `az configure --defaults acs=<name>`
    - new_agent_count -- None
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acs scale", locals())


def show(name, resource_group):
    '''
    Show the details for a container service.

    Required Parameters:
    - name -- Name of the container service. You can configure the default using `az configure --defaults acs=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acs show", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Wait for a container service to reach a desired state.

    Required Parameters:
    - name -- Name of the container service. You can configure the default using `az configure --defaults acs=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az acs wait", locals())




'''
Manage sensitivity classifications.
'''
from ..... pyaz_utils import _call_az
from . import recommendation


def show(column, name, resource_group, schema, table, workspace_name):
    '''
    Get the sensitivity classification of a given column.

    Required Parameters:
    - column -- The name of column.
    - name -- The SQL pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - schema -- The name of schema.
    - table -- The name of table.
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse sql pool classification show", locals())


def list(name, resource_group, workspace_name, filter=None):
    '''
    Get the sensitivity classifications of a given SQL pool.

    Required Parameters:
    - name -- The SQL pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - filter -- An OData filter expression that filters elements in the collection.
    '''
    return _call_az("az synapse sql pool classification list", locals())


def create(column, information_type, label, name, resource_group, schema, table, workspace_name):
    '''
    Create a column's sensitivity classification.

    Required Parameters:
    - column -- The name of column.
    - information_type -- The information type.
    - label -- The label name.
    - name -- The SQL pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - schema -- The name of schema.
    - table -- The name of table.
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse sql pool classification create", locals())


def delete(column, name, resource_group, schema, table, workspace_name):
    '''
    Delete the sensitivity classification of a given column.

    Required Parameters:
    - column -- The name of column.
    - name -- The SQL pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - schema -- The name of schema.
    - table -- The name of table.
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse sql pool classification delete", locals())


def update(column, name, resource_group, schema, table, workspace_name, information_type=None, label=None):
    '''
    Update a column's sensitivity classification.

    Required Parameters:
    - column -- The name of column.
    - name -- The SQL pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - schema -- The name of schema.
    - table -- The name of table.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - information_type -- The information type.
    - label -- The label name.
    '''
    return _call_az("az synapse sql pool classification update", locals())




'''
Manage an existing web app's container settings.
'''
from .... pyaz_utils import _call_az

def set(name, resource_group, docker_custom_image_name=None, docker_registry_server_password=None, docker_registry_server_url=None, docker_registry_server_user=None, enable_app_service_storage=None, multicontainer_config_file=None, multicontainer_config_type=None, slot=None):
    '''
    Set an existing web app's container settings.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - docker_custom_image_name -- the container custom image name and optionally the tag name
    - docker_registry_server_password -- the container registry server password
    - docker_registry_server_url -- the container registry server url
    - docker_registry_server_user -- the container registry server username
    - enable_app_service_storage -- enables platform storage (custom container only)
    - multicontainer_config_file -- config file for multicontainer apps
    - multicontainer_config_type -- config type
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp config container set", locals())


def delete(name, resource_group, slot=None):
    '''
    Delete an existing web app's container settings.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp config container delete", locals())


def show(name, resource_group, show_multicontainer_config=None, slot=None):
    '''
    Get details of a web app's container settings.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - show_multicontainer_config -- shows decoded config if a multicontainer config is set
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp config container show", locals())




'''
Information on available virtual machine images.
'''
from ... pyaz_utils import _call_az
from . import terms


def list_offers(location, publisher, edge_zone=None):
    '''
    List the VM image offers available in the Azure Marketplace.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - publisher -- image publisher

    Optional Parameters:
    - edge_zone -- The name of edge zone.
    '''
    return _call_az("az vm image list-offers", locals())


def list_publishers(location, edge_zone=None):
    '''
    List the VM image publishers available in the Azure Marketplace.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.

    Optional Parameters:
    - edge_zone -- The name of edge zone.
    '''
    return _call_az("az vm image list-publishers", locals())


def list_skus(location, offer, publisher, edge_zone=None):
    '''
    List the VM image SKUs available in the Azure Marketplace.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - offer -- image offer
    - publisher -- image publisher

    Optional Parameters:
    - edge_zone -- The name of edge zone.
    '''
    return _call_az("az vm image list-skus", locals())


def list(all=None, edge_zone=None, location=None, offer=None, publisher=None, sku=None):
    '''
    List the VM/VMSS images available in the Azure Marketplace.

    Optional Parameters:
    - all -- None
    - edge_zone -- The name of edge zone.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - offer -- image offer
    - publisher -- image publisher
    - sku -- image sku
    '''
    return _call_az("az vm image list", locals())


def accept_terms(offer=None, plan=None, publisher=None, urn=None):
    '''
    Accept Azure Marketplace term so that the image can be used to create VMs

    Optional Parameters:
    - offer -- image offer
    - plan -- image billing plan
    - publisher -- image publisher
    - urn -- URN, in format of 'publisher:offer:sku:version' or 'publisher:offer:sku:edge_zone:version'. If specified, other argument values can be omitted
    '''
    return _call_az("az vm image accept-terms", locals())


def show(edge_zone=None, location=None, offer=None, publisher=None, sku=None, urn=None, version=None):
    '''
    Get the details for a VM image available in the Azure Marketplace.

    Optional Parameters:
    - edge_zone -- The name of edge zone.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - offer -- image offer
    - publisher -- image publisher
    - sku -- image sku
    - urn -- URN, in format of 'publisher:offer:sku:version' or 'publisher:offer:sku:edge_zone:version'. If specified, other argument values can be omitted
    - version -- image sku's version
    '''
    return _call_az("az vm image show", locals())




'''
Manage a policy assignment's managed identity.
'''
from .... pyaz_utils import _call_az

def assign(name, identity_scope=None, resource_group=None, role=None, scope=None, system_assigned=None, user_assigned=None):
    '''
    Add a system assigned identity or a user assigned identity to a policy assignment.

    Required Parameters:
    - name -- Name of the policy assignment.

    Optional Parameters:
    - identity_scope -- Scope that the system assigned identity can access
    - resource_group -- the resource group where the policy will be applied
    - role -- Role name or id that will be assigned to the managed identity
    - scope -- Scope to which this policy assignment applies.
    - system_assigned -- Provide this flag to use system assigned identity for policy assignment. Check out help for more examples
    - user_assigned -- UserAssigned Identity Id to be used for policy assignment. Check out help for more examples
    '''
    return _call_az("az policy assignment identity assign", locals())


def show(name, resource_group=None, scope=None):
    '''
    Show a policy assignment's managed identity.

    Required Parameters:
    - name -- Name of the policy assignment.

    Optional Parameters:
    - resource_group -- the resource group where the policy will be applied
    - scope -- Scope to which this policy assignment applies.
    '''
    return _call_az("az policy assignment identity show", locals())


def remove(name, resource_group=None, scope=None):
    '''
    Remove a managed identity from a policy assignment.

    Required Parameters:
    - name -- Name of the policy assignment.

    Optional Parameters:
    - resource_group -- the resource group where the policy will be applied
    - scope -- Scope to which this policy assignment applies.
    '''
    return _call_az("az policy assignment identity remove", locals())




'''
Manage Azure NetApp Files (ANF) Snapshot Resources.
'''
from ... pyaz_utils import _call_az
from . import policy


def show(account_name, name, pool_name, resource_group, volume_name):
    '''
    Get the specified ANF snapshot.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - name -- The name of the ANF snapshot
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- Name of the ANF volume.
    '''
    return _call_az("az netappfiles snapshot show", locals())


def list(account_name, pool_name, resource_group, volume_name):
    '''
    List the snapshots of an ANF volume.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- The name of the ANF volume
    '''
    return _call_az("az netappfiles snapshot list", locals())


def delete(account_name, name, pool_name, resource_group, volume_name):
    '''
    Delete the specified ANF snapshot.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - name -- The name of the ANF snapshot
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- Name of the ANF volume.
    '''
    return _call_az("az netappfiles snapshot delete", locals())


def create(account_name, location, name, pool_name, resource_group, volume_name):
    '''
    Create a new Azure NetApp Files (ANF) snapshot.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the ANF snapshot
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- Name of the ANF volume.
    '''
    return _call_az("az netappfiles snapshot create", locals())


def update(account_name, body, name, pool_name, resource_group, volume_name):
    '''
    

    Required Parameters:
    - account_name -- Name of the ANF account.
    - body -- Snapshot object supplied in the body of the operation.
    - name -- The name of the ANF snapshot
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- Name of the ANF volume.
    '''
    return _call_az("az netappfiles snapshot update", locals())




'''
Manage deployment token for the static app
'''
from ... pyaz_utils import _call_az

def list(name, resource_group=None):
    '''
    List the deployment token for the static app.

    Required Parameters:
    - name -- Name of the static site

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az staticwebapp secrets list", locals())


def reset_api_key(name, no_wait=None, resource_group=None):
    '''
    Reset the deployment token for the static app.

    Required Parameters:
    - name -- Name of the static site

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az staticwebapp secrets reset-api-key", locals())




'''
Manage Azure resource level locks.
'''
from ... pyaz_utils import _call_az

def create(lock_type, name, namespace=None, notes=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    Create a resource-level lock.

    Required Parameters:
    - lock_type -- The type of lock restriction.
    - name -- Name of the lock

    Optional Parameters:
    - namespace -- Provider namespace (Ex: 'Microsoft.Provider')
    - notes -- Notes about this lock.
    - parent -- The parent path (Ex: 'resA/myA/resB/myB')
    - resource -- If an ID is given, other resource arguments should not be given.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- The resource type (Ex: 'resC'). Can also accept namespace/type format (Ex: 'Microsoft.Provider/resC')
    '''
    return _call_az("az resource lock create", locals())


def delete(ids=None, name=None, namespace=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    Delete a resource-level lock.

    Optional Parameters:
    - ids -- One or more resource IDs (space-delimited). If provided, no other "Resource Id" arguments should be specified.
    - name -- Name of the lock
    - namespace -- Provider namespace (Ex: 'Microsoft.Provider')
    - parent -- The parent path (Ex: 'resA/myA/resB/myB')
    - resource -- If an ID is given, other resource arguments should not be given.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- The resource type (Ex: 'resC'). Can also accept namespace/type format (Ex: 'Microsoft.Provider/resC')
    '''
    return _call_az("az resource lock delete", locals())


def list(filter_string=None, namespace=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    List lock information in the resource-level.

    Optional Parameters:
    - filter_string -- A query filter to use to restrict the results.
    - namespace -- Provider namespace (Ex: 'Microsoft.Provider')
    - parent -- The parent path (Ex: 'resA/myA/resB/myB')
    - resource -- If an ID is given, other resource arguments should not be given.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- The resource type (Ex: 'resC'). Can also accept namespace/type format (Ex: 'Microsoft.Provider/resC')
    '''
    return _call_az("az resource lock list", locals())


def show(ids=None, name=None, namespace=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    Show the details of a resource-level lock

    Optional Parameters:
    - ids -- One or more resource IDs (space-delimited). If provided, no other "Resource Id" arguments should be specified.
    - name -- Name of the lock
    - namespace -- Provider namespace (Ex: 'Microsoft.Provider')
    - parent -- The parent path (Ex: 'resA/myA/resB/myB')
    - resource -- If an ID is given, other resource arguments should not be given.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- The resource type (Ex: 'resC'). Can also accept namespace/type format (Ex: 'Microsoft.Provider/resC')
    '''
    return _call_az("az resource lock show", locals())


def update(ids=None, lock_type=None, name=None, namespace=None, notes=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    Update a resource-level lock.

    Optional Parameters:
    - ids -- One or more resource IDs (space-delimited). If provided, no other "Resource Id" arguments should be specified.
    - lock_type -- The type of lock restriction.
    - name -- Name of the lock
    - namespace -- Provider namespace (Ex: 'Microsoft.Provider')
    - notes -- Notes about this lock.
    - parent -- The parent path (Ex: 'resA/myA/resB/myB')
    - resource -- If an ID is given, other resource arguments should not be given.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- The resource type (Ex: 'resC'). Can also accept namespace/type format (Ex: 'Microsoft.Provider/resC')
    '''
    return _call_az("az resource lock update", locals())




'''
Commands to manage a DC/OS-orchestrated Azure Container Service.
'''
from ... pyaz_utils import _call_az

def browse(name, resource_group, disable_browser=None, ssh_key_file=None):
    '''
    

    Required Parameters:
    - name -- Name of the container service. You can configure the default using `az configure --defaults acs=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - disable_browser -- Do not open browser after opening a proxy to the cluster web user interface
    - ssh_key_file -- Path to an SSH key file to use.
    '''
    return _call_az("az acs dcos browse", locals())


def install_cli(client_version=None, install_location=None):
    '''
    Download and install the DC/OS command-line tool for a cluster.

    Optional Parameters:
    - client_version -- Version of kubectl to install.
    - install_location -- Path at which to install kubectl.
    '''
    return _call_az("az acs dcos install-cli", locals())




from .... pyaz_utils import _call_az

def show(account_name, resource_group=None):
    '''
    Show the properties of a storage account's blob service.

    Required Parameters:
    - account_name -- The storage account name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account blob-service-properties show", locals())


def update(account_name, add=None, change_feed_retention_days=None, container_delete_retention_days=None, default_service_version=None, delete_retention_days=None, enable_change_feed=None, enable_container_delete_retention=None, enable_delete_retention=None, enable_last_access_tracking=None, enable_restore_policy=None, enable_versioning=None, force_string=None, remove=None, resource_group=None, restore_days=None, set=None):
    '''
    Update the properties of a storage account's blob service.

    Required Parameters:
    - account_name -- The storage account name.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - change_feed_retention_days -- Indicate the duration of changeFeed retention in days. Minimum value is 1 day and maximum value is 146000 days (400 years). A null value indicates an infinite retention of the change feed.(Use `--enable-change-feed` without `--change-feed-days` to indicate null)
    - container_delete_retention_days -- Indicate the number of days that the deleted container should be retained. The minimum specified value can be 1 and the maximum value can be 365.
    - default_service_version -- Indicate the default version to use for requests to the Blob service if an incoming request's version is not specified.
    - delete_retention_days -- None
    - enable_change_feed -- None
    - enable_container_delete_retention -- Enable container delete retention policy for container soft delete when set to true. Disable container delete retention policy when set to false.
    - enable_delete_retention -- None
    - enable_last_access_tracking -- When set to true last access time based tracking policy is enabled.
    - enable_restore_policy -- Enable blob restore policy when it set to true.
    - enable_versioning -- Versioning is enabled if set to true.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - restore_days -- The number of days for the blob can be restored. It should be greater than zero and less than Delete Retention Days.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az storage account blob-service-properties update", locals())




from ... pyaz_utils import _call_az

def list(plan, resource_group):
    '''
    list the virtual network integrations used in an appservice plan

    Required Parameters:
    - plan -- AppService plan
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az appservice vnet-integration list", locals())




from .... pyaz_utils import _call_az

def show(resource_group, workspace_name):
    '''
    Get the SQL Azure Active Directory administrator.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse sql ad-admin show", locals())


def create(display_name, object_id, resource_group, workspace_name, no_wait=None):
    '''
    Create the SQL Azure Active Directory administrator.

    Required Parameters:
    - display_name -- Display name of the Azure AD administrator user or group.
    - object_id -- The unique ID of the Azure AD administrator.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse sql ad-admin create", locals())


def update(resource_group, workspace_name, add=None, display_name=None, force_string=None, no_wait=None, object_id=None, remove=None, set=None):
    '''
    Update the SQL Azure Active Directory administrator.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - display_name -- Display name of the Azure AD administrator user or group.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - no_wait -- Do not wait for the long-running operation to finish.
    - object_id -- The unique ID of the Azure AD administrator.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az synapse sql ad-admin update", locals())


def delete(resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Delete the SQL Azure Active Directory administrator.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse sql ad-admin delete", locals())


def wait(resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition is met.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az synapse sql ad-admin wait", locals())




'''
Manage file copy operations.
'''
from .... pyaz_utils import _call_az

def start(destination_path, destination_share, account_key=None, account_name=None, connection_string=None, file_snapshot=None, metadata=None, sas_token=None, source_account_key=None, source_account_name=None, source_blob=None, source_container=None, source_path=None, source_sas=None, source_share=None, source_snapshot=None, source_uri=None, timeout=None):
    '''
    Copy a file asynchronously.

    Required Parameters:
    - destination_path -- The path to the file within the file share.
    - destination_share -- Name of the destination share. The share must exist.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - file_snapshot -- The file snapshot for the source storage account.
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - source_account_key -- The storage account key of the source blob.
    - source_account_name -- The storage account name of the source blob.
    - source_blob -- The blob name for the source storage account.
    - source_container -- The container name for the source storage account.
    - source_path -- The file path for the source storage account.
    - source_sas -- The shared access signature for the source storage account.
    - source_share -- The share name for the source storage account.
    - source_snapshot -- The blob snapshot for the source storage account.
    - source_uri --  A URL of up to 2 KB in length that specifies an Azure file or blob. The value should be URL-encoded as it would appear in a request URI. If the source is in another account, the source must either be public or must be authenticated via a shared access signature. If the source is public, no authentication is required. Examples: https://myaccount.file.core.windows.net/myshare/mydir/myfile https://otheraccount.file.core.windows.net/myshare/mydir/myfile?sastoken
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage file copy start", locals())


def cancel(copy_id, destination_path, destination_share, account_key=None, account_name=None, connection_string=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - copy_id --  Copy identifier provided in the copy.id of the original copy_file operation.
    - destination_path -- The path to the file within the file share.
    - destination_share -- Name of the destination share. The share must exist.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage file copy cancel", locals())


def start_batch(account_key=None, account_name=None, connection_string=None, destination_path=None, destination_share=None, dryrun=None, metadata=None, pattern=None, sas_token=None, source_account_key=None, source_account_name=None, source_client=None, source_container=None, source_sas=None, source_share=None, source_uri=None, timeout=None):
    '''
    Copy multiple files or blobs to a file share.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - destination_path -- None
    - destination_share -- None
    - dryrun -- None
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - pattern -- None
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - source_account_key -- None
    - source_account_name -- None
    - source_client -- ==SUPPRESS==
    - source_container -- None
    - source_sas -- None
    - source_share -- None
    - source_uri -- None
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage file copy start-batch", locals())




'''
Manage point-in-time copies of managed disks, native blobs, or other snapshots.
'''
from .. pyaz_utils import _call_az

def create(name, resource_group, accelerated_network=None, copy_start=None, disk_access=None, disk_encryption_set=None, edge_zone=None, encryption_type=None, for_upload=None, hyper_v_generation=None, incremental=None, location=None, network_access_policy=None, no_wait=None, public_network_access=None, size_gb=None, sku=None, source=None, source_storage_account_id=None, tags=None):
    '''
    Create a snapshot.

    Required Parameters:
    - name -- The name of the snapshot
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - accelerated_network -- Customers can set on Managed Disks or Snapshots to enable the accelerated networking if the OS disk image support.
    - copy_start -- Create snapshot by using a deep copy process, where the resource creation is considered complete only after all data has been copied from the source.
    - disk_access -- Name or ID of the disk access resource for using private endpoints on disks.
    - disk_encryption_set -- Name or ID of disk encryption set that is used to encrypt the disk.
    - edge_zone -- The name of edge zone.
    - encryption_type -- Encryption type. EncryptionAtRestWithPlatformKey: Disk is encrypted with XStore managed key at rest. It is the default encryption type. EncryptionAtRestWithCustomerKey: Disk is encrypted with Customer managed key at rest.
    - for_upload -- Create the snapshot for uploading blobs later on through storage commands. Run "az snapshot grant-access --access-level Write" to retrieve the snapshot's SAS token.
    - hyper_v_generation -- The hypervisor generation of the Virtual Machine. Applicable to OS disks only.
    - incremental -- Whether a snapshot is incremental. Incremental snapshots on the same disk occupy less space than full snapshots and can be diffed
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`. If location is not specified and no default location specified, location will be automatically set as same as the resource group.
    - network_access_policy -- Policy for accessing the disk via network.
    - no_wait -- Do not wait for the long-running operation to finish.
    - public_network_access -- Customers can set on Managed Disks or Snapshots to control the export policy on the disk.
    - size_gb -- size in GB. Max size: 4095 GB (certain preview disks can be larger).
    - sku -- None
    - source -- source to create the disk/snapshot from, including unmanaged blob uri, managed disk id or name, or snapshot id or name
    - source_storage_account_id -- used when source blob is in a different subscription
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az snapshot create", locals())


def delete(name, resource_group):
    '''
    

    Required Parameters:
    - name -- The name of the snapshot
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az snapshot delete", locals())


def grant_access(duration_in_seconds, name, resource_group, access_level=None):
    '''
    Grant read access to a snapshot.

    Required Parameters:
    - duration_in_seconds -- Time duration in seconds until the SAS access expires
    - name -- The name of the snapshot
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - access_level -- access level
    '''
    return _call_az("az snapshot grant-access", locals())


def list(resource_group=None):
    '''
    List snapshots.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az snapshot list", locals())


def revoke_access(name, resource_group):
    '''
    Revoke read access to a snapshot.

    Required Parameters:
    - name -- The name of the snapshot
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az snapshot revoke-access", locals())


def show(name, resource_group):
    '''
    

    Required Parameters:
    - name -- The name of the snapshot
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az snapshot show", locals())


def update(name, resource_group, accelerated_network=None, add=None, disk_access=None, disk_encryption_set=None, encryption_type=None, force_string=None, network_access_policy=None, no_wait=None, public_network_access=None, remove=None, set=None, sku=None):
    '''
    Update a snapshot.

    Required Parameters:
    - name -- The name of the snapshot
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - accelerated_network -- Customers can set on Managed Disks or Snapshots to enable the accelerated networking if the OS disk image support.
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - disk_access -- Name or ID of the disk access resource for using private endpoints on disks.
    - disk_encryption_set -- Name or ID of disk encryption set that is used to encrypt the disk.
    - encryption_type -- Encryption type. EncryptionAtRestWithPlatformKey: Disk is encrypted with XStore managed key at rest. It is the default encryption type. EncryptionAtRestWithCustomerKey: Disk is encrypted with Customer managed key at rest.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - network_access_policy -- Policy for accessing the disk via network.
    - no_wait -- Do not wait for the long-running operation to finish.
    - public_network_access -- Customers can set on Managed Disks or Snapshots to control the export policy on the disk.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - sku -- None
    '''
    return _call_az("az snapshot update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a snapshot is met.

    Required Parameters:
    - name -- The name of the snapshot
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az snapshot wait", locals())




'''
Manage pending certificate creation operations.
'''
from .... pyaz_utils import _call_az

def merge(file, name, vault_name, certificate_attributes=None, disabled=None, expires=None, not_before=None, tags=None):
    '''
    

    Required Parameters:
    - file -- File containing the certificate or certificate chain to merge.
    - name -- Name of the pending certificate.
    - vault_name -- Name of the Vault.

    Optional Parameters:
    - certificate_attributes -- ==SUPPRESS==
    - disabled -- Create certificate in disabled state.
    - expires -- Expiration UTC datetime  (Y-m-d'T'H:M:S'Z').
    - not_before -- Key not usable before the provided UTC datetime  (Y-m-d'T'H:M:S'Z').
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az keyvault certificate pending merge", locals())


def show(name, vault_name):
    '''
    

    Required Parameters:
    - name -- Name of the pending certificate.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault certificate pending show", locals())


def delete(name, vault_name):
    '''
    

    Required Parameters:
    - name -- Name of the pending certificate.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault certificate pending delete", locals())




'''
Manage partner namespaces.
'''
from .... pyaz_utils import _call_az
from . import event_channel, key


def show(name, resource_group):
    '''
    Get the details of a partner namespace.

    Required Parameters:
    - name -- Name of the partner namespace.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventgrid partner namespace show", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete a partner namespace.

    Required Parameters:
    - name -- Name of the partner namespace.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az eventgrid partner namespace delete", locals())


def list(odata_query=None, resource_group=None):
    '''
    List available partner namespaces.

    Optional Parameters:
    - odata_query -- The OData query used for filtering the list results. Filtering is currently allowed on the Name property only. The supported operations include: CONTAINS, eq (for equal), ne (for not equal), AND, OR and NOT.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventgrid partner namespace list", locals())


def create(name, partner_registration_id, resource_group, location=None, tags=None):
    '''
    Create a partner namespace.

    Required Parameters:
    - name -- Name of the partner namespace.
    - partner_registration_id -- The fully qualified ARM Id of the partner registration that should be associated with this partner namespace. This takes the following format: /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.EventGrid/partnerRegistrations/{partnerRegistrationName}.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az eventgrid partner namespace create", locals())




from ... pyaz_utils import _call_az

def list(name, resource_group, slot=None):
    '''
    list the hybrid-connections on a functionapp

    Required Parameters:
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp hybrid-connection list", locals())


def add(hybrid_connection, name, namespace, resource_group, slot=None):
    '''
    add an existing hybrid-connection to a functionapp

    Required Parameters:
    - hybrid_connection -- Hybrid connection name
    - name -- name of the function app
    - namespace -- Hybrid connection namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp hybrid-connection add", locals())


def remove(hybrid_connection, name, namespace, resource_group, slot=None):
    '''
    remove a hybrid-connection from a functionapp

    Required Parameters:
    - hybrid_connection -- Hybrid connection name
    - name -- name of the function app
    - namespace -- Hybrid connection namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp hybrid-connection remove", locals())




from .... pyaz_utils import _call_az

def create(name, resource_group, vm, capture_limit=None, capture_size=None, file_path=None, filters=None, storage_account=None, storage_path=None, time_limit=None):
    '''
    Create and start a packet capture session.

    Required Parameters:
    - name -- Name of the packet capture session.
    - resource_group -- Name of the resource group the target VM is in.
    - vm -- Name or ID of the VM to target. If the name of the VM is provided, the --resource-group is required.

    Optional Parameters:
    - capture_limit -- None
    - capture_size -- None
    - file_path -- None
    - filters -- None
    - storage_account -- None
    - storage_path -- None
    - time_limit -- None
    '''
    return _call_az("az network watcher packet-capture create", locals())


def show(location, name, network_watcher_name=None):
    '''
    Show details of a packet capture session.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the packet capture session.

    Optional Parameters:
    - network_watcher_name -- ==SUPPRESS==
    '''
    return _call_az("az network watcher packet-capture show", locals())


def show_status(location, name, network_watcher_name=None):
    '''
    Show the status of a packet capture session.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name given to the packet capture session.

    Optional Parameters:
    - network_watcher_name -- ==SUPPRESS==
    '''
    return _call_az("az network watcher packet-capture show-status", locals())


def delete(location, name, network_watcher_name=None):
    '''
    Delete a packet capture session.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the packet capture session.

    Optional Parameters:
    - network_watcher_name -- ==SUPPRESS==
    '''
    return _call_az("az network watcher packet-capture delete", locals())


def stop(location, name, network_watcher_name=None):
    '''
    Stop a running packet capture session.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the packet capture session.

    Optional Parameters:
    - network_watcher_name -- ==SUPPRESS==
    '''
    return _call_az("az network watcher packet-capture stop", locals())


def list(location, network_watcher_name=None):
    '''
    List all packet capture sessions within a resource group.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.

    Optional Parameters:
    - network_watcher_name -- ==SUPPRESS==
    '''
    return _call_az("az network watcher packet-capture list", locals())




from .... pyaz_utils import _call_az

def list(elastic_pool, resource_group, server):
    '''
    

    Required Parameters:
    - elastic_pool -- Name of the Azure SQL Elastic Pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql elastic-pool op list", locals())


def cancel(elastic_pool, name, resource_group, server):
    '''
    

    Required Parameters:
    - elastic_pool -- Name of the Azure SQL Elastic Pool.
    - name -- The unique name of the operation to cancel.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql elastic-pool op cancel", locals())




from .... pyaz_utils import _call_az

def delete(name, resource_group, service_name):
    '''
    Delete a private link service endpoint connection.

    Required Parameters:
    - name -- Name of the private endpoint connection. List them by using "az network private-link-service show".
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- Name of the private link service.
    '''
    return _call_az("az network private-link-service connection delete", locals())


def update(connection_status, name, resource_group, service_name, action_required=None, description=None):
    '''
    Update a private link service endpoint connection.

    Required Parameters:
    - connection_status -- Indicates whether the connection has been Approved/Rejected/Removed by the owner of the service.
    - name -- Name of the private endpoint connection. List them by using "az network private-link-service show".
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- Name of the private link service.

    Optional Parameters:
    - action_required -- A message indicating if changes on the service provider require any updates on the consumer.
    - description -- The reason for approval/rejection of the connection.
    '''
    return _call_az("az network private-link-service connection update", locals())




from .... pyaz_utils import _call_az

def create(resource_group, server_name, display_name=None, no_wait=None, object_id=None):
    '''
    Create an Active Directory Administrator for PostgreSQL server.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.

    Optional Parameters:
    - display_name -- Display name of the Azure AD administrator user or group.
    - no_wait -- Do not wait for the long-running operation to finish.
    - object_id -- The unique ID of the Azure AD administrator.
    '''
    return _call_az("az postgres server ad-admin create", locals())


def list(resource_group, server_name):
    '''
    List all Active Directory Administrators for PostgreSQL server.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    '''
    return _call_az("az postgres server ad-admin list", locals())


def delete(resource_group, server_name, yes=None):
    '''
    Delete an Active Directory Administrator for PostgreSQL server.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az postgres server ad-admin delete", locals())


def show(resource_group, server_name):
    '''
    Get Active Directory Administrator information for a PostgreSQL server.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    '''
    return _call_az("az postgres server ad-admin show", locals())


def wait(resource_group, server_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the PostgreSQL server Active Directory Administrator is met.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az postgres server ad-admin wait", locals())




from .... pyaz_utils import _call_az

def list(instance_id, location):
    '''
    List all the versions of all the sql databases that were created / modified / deleted in the given restorable account.

    Required Parameters:
    - instance_id -- InstanceId of the Account
    - location -- Location
    '''
    return _call_az("az cosmosdb sql restorable-database list", locals())




from ... pyaz_utils import _call_az

def show():
    return _call_az("az ad signed-in-user show", locals())


def list_owned_objects(type=None):
    '''
    Get the list of directory objects that are owned by the user

    Optional Parameters:
    - type -- object type filter, e.g. "application", "servicePrincipal"  "group", etc
    '''
    return _call_az("az ad signed-in-user list-owned-objects", locals())




'''
Manage jobs for a transform.
'''
from ... pyaz_utils import _call_az

def show(account_name, name, resource_group, transform_name):
    '''
    Show the details of a job.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the job.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - transform_name -- The name of the transform.
    '''
    return _call_az("az ams job show", locals())


def list(account_name, resource_group, transform_name, filter=None, orderby=None):
    '''
    List all the jobs of a transform within an Azure Media Services account.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - transform_name -- The name of the transform.

    Optional Parameters:
    - filter -- Restricts the set of items returned.
    - orderby -- Specifies the key by which the result collection should be ordered.
    '''
    return _call_az("az ams job list", locals())


def delete(account_name, name, resource_group, transform_name):
    '''
    Delete a job.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the job.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - transform_name -- The name of the transform.
    '''
    return _call_az("az ams job delete", locals())


def cancel(account_name, name, resource_group, transform_name, delete=None):
    '''
    Cancel a job.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the job.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - transform_name -- The name of the transform.

    Optional Parameters:
    - delete -- Delete the job being cancelled.
    '''
    return _call_az("az ams job cancel", locals())


def start(account_name, name, output_assets, resource_group, transform_name, base_uri=None, correlation_data=None, description=None, files=None, input_asset_name=None, label=None, priority=None):
    '''
    Start a job.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the job.
    - output_assets -- Space-separated assets in 'assetName=label' format. An asset without label can be sent like this: 'assetName='
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - transform_name -- The name of the transform.

    Optional Parameters:
    - base_uri -- Base uri for http job input. It will be concatenated with provided file names. If no base uri is given, then the provided file list is assumed to be fully qualified uris.
    - correlation_data -- Space-separated correlation data in 'key[=value]' format. This customer provided data will be returned in Job and JobOutput state events.
    - description -- The job description.
    - files -- Space-separated list of files. It can be used to tell the service to only use the files specified from the input asset.
    - input_asset_name -- The name of the input asset.
    - label -- A label that is assigned to a Job Input that is used to satisfy a reference used in the Transform. For example, a Transform can be authored to take an image file with the label 'xyz' and apply it as an overlay onto the input video before it is encoded. When submitting a Job, exactly one of the JobInputs should be the image file, and it should have the label 'xyz'.
    - priority -- The priority with which the job should be processed.
    '''
    return _call_az("az ams job start", locals())


def update(account_name, name, resource_group, transform_name, add=None, description=None, force_string=None, priority=None, remove=None, set=None):
    '''
    Update an existing job.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the job.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - transform_name -- The name of the transform.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - description -- The job description.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - priority -- The priority with which the job should be processed.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az ams job update", locals())




from .... pyaz_utils import _call_az

def show(name, resource, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None):
    '''
    

    Required Parameters:
    - name -- The name of the diagnostic setting.
    - resource -- Name or ID of the target resource.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_namespace -- Target resource provider namespace.
    - resource_parent -- Target resource parent path, if applicable.
    - resource_type -- Target resource type. Can also accept namespace/type format (Ex: 'Microsoft.Compute/virtualMachines')
    '''
    return _call_az("az monitor diagnostic-settings categories show", locals())


def list(resource, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None):
    '''
    List the diagnostic settings categories for the specified resource.

    Required Parameters:
    - resource -- Name or ID of the target resource.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_namespace -- Target resource provider namespace.
    - resource_parent -- Target resource parent path, if applicable.
    - resource_type -- Target resource type. Can also accept namespace/type format (Ex: 'Microsoft.Compute/virtualMachines')
    '''
    return _call_az("az monitor diagnostic-settings categories list", locals())




from ..... pyaz_utils import _call_az

def list(name, namespace_name, resource_group):
    '''
    List the keys and connection strings of Authorization Rule for Relay Service Namespace

    Required Parameters:
    - name -- Name of Namespace Authorization Rule
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az relay namespace authorization-rule keys list", locals())


def renew(key, name, namespace_name, resource_group, key_value=None):
    '''
    Regenerate keys of Authorization Rule for the Relay Service Namespace.

    Required Parameters:
    - key -- specifies Primary or Secondary key needs to be reset
    - name -- Name of Namespace Authorization Rule
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - key_value -- Optional, if the key value provided, is set for KeyType or autogenerated Key value set for keyType.
    '''
    return _call_az("az relay namespace authorization-rule keys renew", locals())




'''
Commands to manage CLI objects cached using the `--defer` argument.
'''
from .. pyaz_utils import _call_az

def list():
    '''
    List the contents of the object cache.
    '''
    return _call_az("az cache list", locals())


def show(name, resource_group, resource_type):
    '''
    Show the contents of a specific object in the cache.

    Required Parameters:
    - name -- The resource name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- The resource type.
    '''
    return _call_az("az cache show", locals())


def delete(name, resource_group, resource_type):
    '''
    Delete an object from the cache.

    Required Parameters:
    - name -- The resource name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- The resource type.
    '''
    return _call_az("az cache delete", locals())


def purge():
    '''
    Clear the entire CLI object cache.
    '''
    return _call_az("az cache purge", locals())




from .... pyaz_utils import _call_az
from . import connection, peer_connection


def create(circuit_name, peer_asn, peering_type, primary_peer_subnet, resource_group, secondary_peer_subnet, vlan_id, advertised_public_prefixes=None, customer_asn=None, ip_version=None, legacy_mode=None, route_filter=None, routing_registry_name=None, shared_key=None):
    '''
    Create peering settings for an ExpressRoute circuit.

    Required Parameters:
    - circuit_name -- ExpressRoute circuit name.
    - peer_asn -- Autonomous system number of the customer/connectivity provider.
    - peering_type -- BGP peering type for the circuit.
    - primary_peer_subnet -- /30(ipv4) or /126(ipv6) subnet used to configure IP addresses for primary interface.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - secondary_peer_subnet -- /30(ipv4) or /126(ipv6) subnet used to configure IP addresses for secondary interface.
    - vlan_id -- Identifier used to identify the customer.

    Optional Parameters:
    - advertised_public_prefixes -- Space-separated list of prefixes to be advertised through the BGP peering.
    - customer_asn -- Autonomous system number of the customer.
    - ip_version -- The IP version to update Microsoft Peering settings for.
    - legacy_mode -- Integer representing the legacy mode of the peering.
    - route_filter -- Name or ID of a route filter to apply to the peering settings.
    - routing_registry_name -- Internet Routing Registry / Regional Internet Registry
    - shared_key -- Key for generating an MD5 for the BGP session.
    '''
    return _call_az("az network express-route peering create", locals())


def delete(circuit_name, name, resource_group):
    '''
    Delete peering settings.

    Required Parameters:
    - circuit_name -- ExpressRoute circuit name.
    - name -- The name of the peering
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route peering delete", locals())


def show(circuit_name, name, resource_group):
    '''
    Get the details of an express route peering.

    Required Parameters:
    - circuit_name -- ExpressRoute circuit name.
    - name -- The name of the peering
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route peering show", locals())


def list(circuit_name, resource_group):
    '''
    List peering settings of an ExpressRoute circuit.

    Required Parameters:
    - circuit_name -- ExpressRoute circuit name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route peering list", locals())


def get_stats(circuit_name, name, resource_group):
    '''
    Get all traffic stats of an ExpressRoute peering.

    Required Parameters:
    - circuit_name -- ExpressRoute circuit name.
    - name -- The name of the peering
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route peering get-stats", locals())


def update(circuit_name, name, resource_group, add=None, advertised_public_prefixes=None, customer_asn=None, force_string=None, ip_version=None, legacy_mode=None, peer_asn=None, primary_peer_subnet=None, remove=None, route_filter=None, routing_registry_name=None, secondary_peer_subnet=None, set=None, shared_key=None, vlan_id=None):
    '''
    Update peering settings of an ExpressRoute circuit.

    Required Parameters:
    - circuit_name -- ExpressRoute circuit name.
    - name -- The name of the peering
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - advertised_public_prefixes -- Space-separated list of prefixes to be advertised through the BGP peering.
    - customer_asn -- Autonomous system number of the customer.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - ip_version -- The IP version to update Microsoft Peering settings for.
    - legacy_mode -- Integer representing the legacy mode of the peering.
    - peer_asn -- Autonomous system number of the customer/connectivity provider.
    - primary_peer_subnet -- /30(ipv4) or /126(ipv6) subnet used to configure IP addresses for primary interface.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - route_filter -- Name or ID of a route filter to apply to the peering settings.
    - routing_registry_name -- Internet Routing Registry / Regional Internet Registry
    - secondary_peer_subnet -- /30(ipv4) or /126(ipv6) subnet used to configure IP addresses for secondary interface.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - shared_key -- Key for generating an MD5 for the BGP session.
    - vlan_id -- Identifier used to identify the customer.
    '''
    return _call_az("az network express-route peering update", locals())




'''
Manage Data Lake Analytics catalog tables.
'''
from .... pyaz_utils import _call_az

def show(account, database_name, schema_name, table_name):
    '''
    

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - database_name -- The name of the database containing the table.
    - schema_name -- The name of the schema containing the table.
    - table_name -- The name of the table.
    '''
    return _call_az("az dla catalog table show", locals())


def list(account, database_name, schema_name=None):
    '''
    List tables in a database or schema.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - database_name -- None

    Optional Parameters:
    - schema_name -- None
    '''
    return _call_az("az dla catalog table list", locals())




from ... pyaz_utils import _call_az

def show(name, node_name, resource_group, workspace_name):
    '''
    Get self-hosted integration runtime node information.

    Required Parameters:
    - name -- The integration runtime name.
    - node_name -- The integration runtime node name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse integration-runtime-node show", locals())


def update(auto_update, name, node_name, resource_group, update_delay_offset, workspace_name):
    '''
    Update self-hosted integration runtime node.

    Required Parameters:
    - auto_update -- Enable or disable the self-hosted integration runtime auto-update.
    - name -- The integration runtime name.
    - node_name -- The integration runtime node name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - update_delay_offset -- The time of the day for the self-hosted integration runtime auto-update.
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse integration-runtime-node update", locals())


def delete(name, node_name, resource_group, workspace_name, yes=None):
    '''
    Remove a self-hosted integration runtime node.

    Required Parameters:
    - name -- The integration runtime name.
    - node_name -- The integration runtime node name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse integration-runtime-node delete", locals())


def get_ip_address(name, node_name, resource_group, workspace_name):
    '''
    Get self-hosted integration runtime node ip.

    Required Parameters:
    - name -- The integration runtime name.
    - node_name -- The integration runtime node name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse integration-runtime-node get-ip-address", locals())




from ..... pyaz_utils import _call_az

def delete(name, resource_group, zone_name, if_match=None, no_wait=None, yes=None):
    '''
    Delete a virtual network link to the specified Private DNS zone.

    Required Parameters:
    - name -- The name of the virtual network link to the specified Private DNS zone.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- The name of the Private DNS zone.

    Optional Parameters:
    - if_match -- The ETag of the virtual network link to the Private DNS zone. Omit this value to always delete the current zone. Specify the last-seen ETag value to prevent accidentally deleting any concurrent changes.
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az network private-dns link vnet delete", locals())


def show(name, resource_group, zone_name):
    '''
    Get a virtual network link to the specified Private DNS zone.

    Required Parameters:
    - name -- The name of the virtual network link to the specified Private DNS zone.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- The name of the Private DNS zone.
    '''
    return _call_az("az network private-dns link vnet show", locals())


def list(resource_group, zone_name, top=None):
    '''
    List the virtual network links to the specified Private DNS zone.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- The name of the Private DNS zone.

    Optional Parameters:
    - top -- The maximum number of virtual network links to return. If not specified, returns up to 100 virtual network links.
    '''
    return _call_az("az network private-dns link vnet list", locals())


def create(name, registration_enabled, resource_group, virtual_network, zone_name, no_wait=None, tags=None):
    '''
    Create a virtual network link to the specified Private DNS zone.

    Required Parameters:
    - name -- The name of the virtual network link to the specified Private DNS zone.
    - registration_enabled -- Specify if the link is registration enabled.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - virtual_network -- Name or ID of the virtual network.
    - zone_name -- The name of the Private DNS zone.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az network private-dns link vnet create", locals())


def update(name, resource_group, zone_name, add=None, force_string=None, if_match=None, no_wait=None, registration_enabled=None, remove=None, set=None, tags=None):
    '''
    Update a virtual network link's properties. Does not modify virtual network within the link.

    Required Parameters:
    - name -- The name of the virtual network link to the specified Private DNS zone.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- The name of the Private DNS zone.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - if_match -- None
    - no_wait -- Do not wait for the long-running operation to finish.
    - registration_enabled -- Specify if the link is registration enabled.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az network private-dns link vnet update", locals())


def wait(name, resource_group, zone_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the virtual network link to the specified Private DNS zone is met.

    Required Parameters:
    - name -- The name of the virtual network link to the specified Private DNS zone.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- The name of the Private DNS zone.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az network private-dns link vnet wait", locals())




from ..... pyaz_utils import _call_az

def show(name, resource_group, security_alert_policy_name, workspace_name):
    '''
    Get a SQL pool's threat detection policy.

    Required Parameters:
    - name -- The SQL pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - security_alert_policy_name -- Name of the security alert policy.
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse sql pool threat-policy show", locals())


def update(name, resource_group, workspace_name, add=None, disabled_alerts=None, email_account_admins=None, email_addresses=None, force_string=None, remove=None, retention_days=None, security_alert_policy_name=None, set=None, state=None, storage_account=None, storage_endpoint=None, storage_key=None):
    '''
    Update a SQL pool's threat detection policy.

    Required Parameters:
    - name -- The SQL pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - disabled_alerts -- List of disabled alerts.
    - email_account_admins -- Whether the alert is sent to the account administrators.
    - email_addresses -- List of email addresses that alerts are sent to.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - retention_days -- The number of days to retain threat detection logs.
    - security_alert_policy_name -- Name of the security alert policy.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - state -- Threat detection policy state
    - storage_account -- Name of the storage account.
    - storage_endpoint -- The storage account endpoint.
    - storage_key -- Access key for the storage account.
    '''
    return _call_az("az synapse sql pool threat-policy update", locals())




from ... pyaz_utils import _call_az

def list(resource_group, service_name):
    '''
    

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the search service.
    '''
    return _call_az("az search shared-private-link-resource list", locals())


def show(name, resource_group, service_name):
    '''
    

    Required Parameters:
    - name -- The name of the shared private link resource managed by the Azure Cognitive Search service within the specified resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the search service.
    '''
    return _call_az("az search shared-private-link-resource show", locals())


def delete(name, resource_group, service_name, yes=None):
    '''
    

    Required Parameters:
    - name -- The name of the shared private link resource managed by the Azure Cognitive Search service within the specified resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the search service.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az search shared-private-link-resource delete", locals())


def create(group_id, name, resource_group, resource_id, service_name, no_wait=None, request_message=None):
    '''
    

    Required Parameters:
    - group_id -- The group id of the resource; for example: blob, sql or vault.
    - name -- Name of the shared private link resource.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_id -- Fully qualified resource ID for the resource. for example: /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/ {resourceProviderNamespace}/{resourceType}/{resourceName}.
    - service_name -- The name of the search service.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - request_message -- Custom request message when creating or updating the shared privatelink resources.
    '''
    return _call_az("az search shared-private-link-resource create", locals())


def update(group_id, name, request_message, resource_group, resource_id, service_name, no_wait=None):
    '''
    

    Required Parameters:
    - group_id -- The group id of the resource; for example: blob, sql or vault.
    - name -- Name of the shared private link resource.
    - request_message -- Custom request message when creating or updating the shared privatelink resources.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_id -- Fully qualified resource ID for the resource; for example: /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/ {resourceProviderNamespace}/{resourceType}/{resourceName}.
    - service_name -- The name of the search service.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az search shared-private-link-resource update", locals())


def wait(name, resource_group, service_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Wait for async shared private link resource operations.

    Required Parameters:
    - name -- The name of the shared private link resource managed by the Azure Cognitive Search service within the specified resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the search service.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az search shared-private-link-resource wait", locals())




from ..... pyaz_utils import _call_az

def list(resource_group, workspace_name):
    '''
    List all the intelligence packs possible and whether they are enabled or disabled for a given workspace.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- Name of the Log Analytics Workspace.
    '''
    return _call_az("az monitor log-analytics workspace pack list", locals())


def enable(name, resource_group, workspace_name):
    '''
    Enable an intelligence pack for a given workspace.

    Required Parameters:
    - name -- The name of the intelligence pack to be enabled.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- Name of the Log Analytics Workspace.
    '''
    return _call_az("az monitor log-analytics workspace pack enable", locals())


def disable(name, resource_group, workspace_name):
    '''
    Disable an intelligence pack for a given workspace.

    Required Parameters:
    - name -- The name of the intelligence pack to be disabled.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- Name of the Log Analytics Workspace.
    '''
    return _call_az("az monitor log-analytics workspace pack disable", locals())




'''
Manage Azure bastion host.
'''
from ... pyaz_utils import _call_az

def create(name, public_ip_address, resource_group, vnet_name, location=None, scale_units=None, sku=None, tags=None):
    '''
    Create a Azure bastion host machine.

    Required Parameters:
    - name -- Name of the bastion host.
    - public_ip_address -- Name or ID of the Azure public IP. The SKU of the public IP must be Standard.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vnet_name -- Name of the virtual network. It must have a subnet called AzureBastionSubnet.

    Optional Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - scale_units -- The scale units for the Bastion Host resource, which minimum is 2 and maximum is 50.
    - sku -- The SKU of this Bastion Host.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az network bastion create", locals())


def show(name, resource_group):
    '''
    Show a Azure bastion host machine.

    Required Parameters:
    - name -- Name of the bastion host.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network bastion show", locals())


def list(resource_group=None):
    '''
    List all Azure bastion host machines.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network bastion list", locals())


def ssh(auth_type, name, resource_group, target_resource_id, resource_port=None, ssh_key=None, username=None):
    '''
    SSH to a virtual machine using Tunneling from Azure Bastion.

    Required Parameters:
    - auth_type -- Auth type to use for SSH connections.
    - name -- Name of the bastion host.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - target_resource_id -- ResourceId of the target Virtual Machine.

    Optional Parameters:
    - resource_port -- Resource port of the target VM to which the bastion will connect.
    - ssh_key -- SSH key file location for SSH connections.
    - username -- User name for SSH connections.
    '''
    return _call_az("az network bastion ssh", locals())


def rdp(name, resource_group, target_resource_id, resource_port=None):
    '''
    RDP to target Virtual Machine using Tunneling from Azure Bastion.

    Required Parameters:
    - name -- Name of the bastion host.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - target_resource_id -- ResourceId of the target Virtual Machine.

    Optional Parameters:
    - resource_port -- Resource port of the target VM to which the bastion will connect.
    '''
    return _call_az("az network bastion rdp", locals())


def tunnel(name, port, resource_group, resource_port, target_resource_id, timeout=None):
    '''
    Show a Azure bastion host machine.

    Required Parameters:
    - name -- Name of the bastion host.
    - port -- Local port to use for the tunneling.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_port -- Resource port of the target VM to which the bastion will connect.
    - target_resource_id -- ResourceId of the target Virtual Machine.

    Optional Parameters:
    - timeout -- Timeout for connection to bastion host tunnel.
    '''
    return _call_az("az network bastion tunnel", locals())


def delete(name, resource_group):
    '''
    Delete a Azure bastion host machine.

    Required Parameters:
    - name -- Name of the bastion host.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network bastion delete", locals())




from ... pyaz_utils import _call_az
from . import alert


def list(caller=None, correlation_id=None, end_time=None, filters=None, max_events=None, namespace=None, offset=None, resource_group=None, resource_id=None, select=None, start_time=None, status=None):
    '''
    List and query activity log events.

    Optional Parameters:
    - caller -- None
    - correlation_id -- None
    - end_time -- End time of the query. Defaults to the current time. Format: date (yyyy-mm-dd) time (hh:mm:ss.xxxxx) timezone (+/-hh:mm)
    - filters -- OData filters. Will ignore other filter arguments.
    - max_events -- None
    - namespace -- None
    - offset -- None
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_id -- None
    - select -- None
    - start_time -- Start time of the query. Format: date (yyyy-mm-dd) time (hh:mm:ss.xxxxx) timezone (+/-hh:mm)
    - status -- None
    '''
    return _call_az("az monitor activity-log list", locals())


def list_categories():
    '''
    List the event categories of activity logs.
    '''
    return _call_az("az monitor activity-log list-categories", locals())




'''
Manage Azure Media Services resources.
'''
from .. pyaz_utils import _call_az
from . import account, account_filter, asset, asset_filter, content_key_policy, job, live_event, live_output, streaming_endpoint, streaming_locator, streaming_policy, transform




from ..... pyaz_utils import _call_az

def create(gateway_name, name, path_map_name, paths, resource_group, address_pool=None, http_settings=None, no_wait=None, redirect_config=None, rewrite_rule_set=None, waf_policy=None):
    '''
    Create a rule for a URL path map.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- The name of the url-path-map rule.
    - path_map_name -- The name of the URL path map.
    - paths -- Space-separated list of paths to associate with the rule. Valid paths start and end with "/" (ex: "/bar/")
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - address_pool -- The name or ID of the backend address pool to use with the created rule.
    - http_settings -- The name or ID of the HTTP settings to use with the created rule.
    - no_wait -- Do not wait for the long-running operation to finish.
    - redirect_config -- The name or ID of the redirect configuration to use with the created rule.
    - rewrite_rule_set -- The name or ID of the rewrite rule set. If not specified, the default for the map will be used.
    - waf_policy -- Name or ID of a Firewall Policy resource.
    '''
    return _call_az("az network application-gateway url-path-map rule create", locals())


def delete(gateway_name, name, path_map_name, resource_group, no_wait=None):
    '''
    Delete a rule of a URL path map.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- The name of the url-path-map rule.
    - path_map_name -- The name of the URL path map.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network application-gateway url-path-map rule delete", locals())




'''
Manage repositories (image names) for Azure Container Registries.
'''
from ... pyaz_utils import _call_az

def list(name, password=None, resource_group=None, suffix=None, top=None, username=None):
    '''
    List repositories in an Azure Container Registry.

    Required Parameters:
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - password -- The password used to log into a container registry
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - suffix -- The tenant suffix in registry login server. You may specify '--suffix tenant' if your registry login server is in the format 'registry-tenant.azurecr.io'. Applicable if you're accessing the registry from a different subscription or you have permission to access images but not the permission to manage the registry resource.
    - top -- Limit the number of items in the results.
    - username -- The username used to log into a container registry
    '''
    return _call_az("az acr repository list", locals())


def show_tags(name, repository, detail=None, orderby=None, password=None, resource_group=None, suffix=None, top=None, username=None):
    '''
    Show tags for a repository in an Azure Container Registry.

    Required Parameters:
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`
    - repository -- The name of the repository.

    Optional Parameters:
    - detail -- Show detailed information.
    - orderby -- Order the items in the results. Default to alphabetical order of names.
    - password -- The password used to log into a container registry
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - suffix -- The tenant suffix in registry login server. You may specify '--suffix tenant' if your registry login server is in the format 'registry-tenant.azurecr.io'. Applicable if you're accessing the registry from a different subscription or you have permission to access images but not the permission to manage the registry resource.
    - top -- Limit the number of items in the results.
    - username -- The username used to log into a container registry
    '''
    return _call_az("az acr repository show-tags", locals())


def show_manifests(name, repository, detail=None, orderby=None, password=None, resource_group=None, suffix=None, top=None, username=None):
    '''
    Show manifests of a repository in an Azure Container Registry.

    Required Parameters:
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`
    - repository -- The name of the repository.

    Optional Parameters:
    - detail -- Show detailed information.
    - orderby -- Order the items in the results. Default to alphabetical order of names.
    - password -- The password used to log into a container registry
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - suffix -- The tenant suffix in registry login server. You may specify '--suffix tenant' if your registry login server is in the format 'registry-tenant.azurecr.io'. Applicable if you're accessing the registry from a different subscription or you have permission to access images but not the permission to manage the registry resource.
    - top -- Limit the number of items in the results.
    - username -- The username used to log into a container registry
    '''
    return _call_az("az acr repository show-manifests", locals())


def show(name, image=None, password=None, repository=None, resource_group=None, suffix=None, username=None):
    '''
    Get the attributes of a repository or image in an Azure Container Registry.

    Required Parameters:
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - image -- The name of the image. May include a tag in the format 'name:tag' or digest in the format 'name@digest'.
    - password -- The password used to log into a container registry
    - repository -- The name of the repository.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - suffix -- The tenant suffix in registry login server. You may specify '--suffix tenant' if your registry login server is in the format 'registry-tenant.azurecr.io'. Applicable if you're accessing the registry from a different subscription or you have permission to access images but not the permission to manage the registry resource.
    - username -- The username used to log into a container registry
    '''
    return _call_az("az acr repository show", locals())


def update(name, delete_enabled=None, image=None, list_enabled=None, password=None, read_enabled=None, repository=None, resource_group=None, suffix=None, username=None, write_enabled=None):
    '''
    Update the attributes of a repository or image in an Azure Container Registry.

    Required Parameters:
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - delete_enabled -- Indicates whether delete operation is allowed.
    - image -- The name of the image. May include a tag in the format 'name:tag' or digest in the format 'name@digest'.
    - list_enabled -- Indicates whether this item shows in list operation results.
    - password -- The password used to log into a container registry
    - read_enabled -- Indicates whether read operation is allowed.
    - repository -- The name of the repository.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - suffix -- The tenant suffix in registry login server. You may specify '--suffix tenant' if your registry login server is in the format 'registry-tenant.azurecr.io'. Applicable if you're accessing the registry from a different subscription or you have permission to access images but not the permission to manage the registry resource.
    - username -- The username used to log into a container registry
    - write_enabled -- Indicates whether write or delete operation is allowed.
    '''
    return _call_az("az acr repository update", locals())


def delete(name, image=None, password=None, repository=None, resource_group=None, suffix=None, username=None, yes=None):
    '''
    Delete a repository or image in an Azure Container Registry.

    Required Parameters:
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - image -- The name of the image. May include a tag in the format 'name:tag' or digest in the format 'name@digest'.
    - password -- The password used to log into a container registry
    - repository -- The name of the repository.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - suffix -- The tenant suffix in registry login server. You may specify '--suffix tenant' if your registry login server is in the format 'registry-tenant.azurecr.io'. Applicable if you're accessing the registry from a different subscription or you have permission to access images but not the permission to manage the registry resource.
    - username -- The username used to log into a container registry
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az acr repository delete", locals())


def untag(image, name, password=None, resource_group=None, suffix=None, username=None):
    '''
    Untag an image in an Azure Container Registry.

    Required Parameters:
    - image -- The name of the image. May include a tag in the format 'name:tag'.
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - password -- The password used to log into a container registry
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - suffix -- The tenant suffix in registry login server. You may specify '--suffix tenant' if your registry login server is in the format 'registry-tenant.azurecr.io'. Applicable if you're accessing the registry from a different subscription or you have permission to access images but not the permission to manage the registry resource.
    - username -- The username used to log into a container registry
    '''
    return _call_az("az acr repository untag", locals())




from ... pyaz_utils import _call_az

def list():
    '''
    List all security assessment results.
    '''
    return _call_az("az security assessment-metadata list", locals())


def show(name):
    '''
    Shows a security assessment.

    Required Parameters:
    - name -- name of the resource to be fetched
    '''
    return _call_az("az security assessment-metadata show", locals())


def create(description, display_name, name, severity, remediation_description=None):
    '''
    Creates a customer managed security assessment type.

    Required Parameters:
    - description -- Detailed string that will help users to understand the assessment and how it is calculated
    - display_name -- Human readable title for this object
    - name -- name of the resource to be fetched
    - severity -- Indicates the importance of the security risk if the assessment is unhealthy

    Optional Parameters:
    - remediation_description -- Detailed string that will help users to understand the different ways to mitigate or fix the security issue
    '''
    return _call_az("az security assessment-metadata create", locals())


def delete(name):
    '''
    Deletes a security assessment type and all it's assessment results.

    Required Parameters:
    - name -- name of the resource to be fetched
    '''
    return _call_az("az security assessment-metadata delete", locals())




from .... pyaz_utils import _call_az

def create(address_prefix, name, next_hop_type, resource_group, route_table_name, next_hop_ip_address=None):
    '''
    Create a route in a route table.

    Required Parameters:
    - address_prefix -- The destination CIDR to which the route applies.
    - name -- Route name
    - next_hop_type -- The type of Azure hop the packet should be sent to.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - route_table_name -- Route table name

    Optional Parameters:
    - next_hop_ip_address -- The IP address packets should be forwarded to when using the VirtualAppliance hop type.
    '''
    return _call_az("az network route-table route create", locals())


def delete(name, resource_group, route_table_name):
    '''
    Delete a route from a route table.

    Required Parameters:
    - name -- Route name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - route_table_name -- Route table name
    '''
    return _call_az("az network route-table route delete", locals())


def show(name, resource_group, route_table_name):
    '''
    Get the details of a route in a route table.

    Required Parameters:
    - name -- Route name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - route_table_name -- Route table name
    '''
    return _call_az("az network route-table route show", locals())


def list(resource_group, route_table_name):
    '''
    List routes in a route table.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - route_table_name -- Route table name
    '''
    return _call_az("az network route-table route list", locals())


def update(name, resource_group, route_table_name, add=None, address_prefix=None, force_string=None, next_hop_ip_address=None, next_hop_type=None, remove=None, set=None):
    '''
    Update a route in a route table.

    Required Parameters:
    - name -- Route name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - route_table_name -- Route table name

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - address_prefix -- The destination CIDR to which the route applies.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - next_hop_ip_address -- The IP address packets should be forwarded to when using the VirtualAppliance hop type.
    - next_hop_type -- The type of Azure hop the packet should be sent to.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network route-table route update", locals())




'''
Manage CORS for Azure SignalR Service.
'''
from ... pyaz_utils import _call_az

def add(allowed_origins, name, resource_group):
    '''
    Add allowed origins to a SignalR Service

    Required Parameters:
    - allowed_origins -- space separated origins that should be allowed to make cross-origin calls (for example: http://example.com:12345). To allow all, use "*"
    - name -- Name of signalr service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az signalr cors add", locals())


def remove(allowed_origins, name, resource_group):
    '''
    Remove allowed origins from a SignalR Service

    Required Parameters:
    - allowed_origins -- space separated origins that should be allowed to make cross-origin calls (for example: http://example.com:12345). To allow all, use "*"
    - name -- Name of signalr service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az signalr cors remove", locals())


def list(name, resource_group):
    '''
    List allowed origins of a SignalR Service

    Required Parameters:
    - name -- Name of signalr service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az signalr cors list", locals())


def update(allowed_origins, name, resource_group):
    '''
    Update allowed origins to a SignalR Service

    Required Parameters:
    - allowed_origins -- space separated origins that should be allowed to make cross-origin calls (for example: http://example.com:12345). To allow all, use "*"
    - name -- Name of signalr service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az signalr cors update", locals())

